@@ -2,7 +2,7 @@
 print.cumres <- function(x,...) {
     cat("\n")
     print(coef(x), ...)
-    cat("\nR =",x$R,"\n")
+    cat("\nBased on ", x$R, " realizations.\n",sep="")
     invisible(x)
 }
 
@@ -16,8 +16,8 @@ summary.cumres <- function(object,...) {
 print.summary.cumres <- function(x,...) {
     cat("\n");
     for (i in 1:length(x$variable)) {
-        if (!is.null(x$KS)) cat("Kolmogorov-Smirnov-test: p-value=", x$KS[i], "\n", sep="")
-        if (!is.null(x$CvM)) cat("Cramer von Mises-test: p-value=", x$CvM[i], "\n", sep="")
+        if (!is.null(x$KS)) cat("Sup-test: p-value=", x$KS[i], "\n", sep="")
+        if (!is.null(x$CvM)) cat("L2-test: p-value=", x$CvM[i], "\n", sep="")
         cat("Based on ", x$R, " realizations. Cumulated residuals ordered by '", x$variable[i], "'.\n", sep="")
         cat("---\n");
     }
